==> plplot-5.12.0.tar.gz: plplot-5.12.0/doc/doxygen/html/search/variables_17.js <==
var searchData=
[
  ['w',['w',['../structlweights.html#af40aaef04f119296b33813a0225e00e3',1,'lweights::w()'],['../structTkDev.html#a4c322c4c38c122f4e60fdd8c2296e85d',1,'TkDev::w()']]],
  ['wdxoff',['wdxoff',['../structPLStream.html#a6916b03e47be96ff859874fa15f98fa6',1,'PLStream']]],
  ['wdxscl',['wdxscl',['../structPLStream.html#a36fef6d794ee3daeb1e22fb9552d499a',1,'PLStream']]],
  ['wdyoff',['wdyoff',['../structPLStream.html#a732b5abcb2edb9375695bd9c61e98272',1,'PLStream']]],
  ['wdyscl',['wdyscl',['../structPLStream.html#a1ddb0104b923970d0889e9bcb9820aef',1,'PLStream']]],
  ['weight',['weight',['../structTextSizeInfo.html#afa663f4b7f4f6c2aa0551b8e27d70eef',1,'TextSizeInfo']]],
  ['weightlookup',['weightLookup',['../cairo_8c.html#a8ee4cf3cd65bc4579b564af38718e76e',1,'cairo.c']]],
  ['weights',['weights',['../structlpi.html#a47f09ca005a3a4725ac531d7c1b4a178',1,'lpi::weights()'],['../structnn__weights.html#aa7ff68d9ad8e6499da44ae1ea326f368',1,'nn_weights::weights()'],['../structnnai.html#a864b1bcffbc680629d3c0efeff6d0529',1,'nnai::weights()'],['../structnnpi.html#a5f9dd37ee1ee5fe193df92df14c81875',1,'nnpi::weights()']]],
  ['which_5fclip',['which_clip',['../structSVG.html#ac28d8f81f49562a61c7de7004a0d80a4',1,'SVG']]],
  ['widgetcmd',['widgetCmd',['../structPlPlotter.html#ac8c81c96fb8f23a67e730995fe5ebb9d',1,'PlPlotter']]],
  ['width',['width',['../structTextSizeInfo.html#ab1af6b6260151c04950802322d3daeaf',1,'TextSizeInfo::width()'],['../structplplot_1_1__N4.html#a0f3ef32d5b1784d76004730694a84a8b',1,'plplot::_N4::width()'],['../structPlFrame.html#acc698d3e2671b7ef5a041c04f01dae1c',1,'PlFrame::width()'],['../structTkDev.html#acd6af46bd1c788770c0615962e8119b6',1,'TkDev::width()'],['../structPlPlotter.html#a0242cfa1d0dc49a4f1ffac8d5ae01459',1,'PlPlotter::width()'],['../structTkwDev.html#a11a01cf9504ca9f31486d9508646c8b4',1,'TkwDev::width()'],['../structPLDisplay.html#ae8787ffc7a95b8ebcd7c991e97c1452c',1,'PLDisplay::width()'],['../structPLStream.html#a5ee6732e0c80f6ee27d5588100f07cb7',1,'PLStream::width()'],['../structXwDev.html#a490aa0f52841cfabe6eaf2bdde560989',1,'XwDev::width()']]],
  ['widthlock',['widthlock',['../structPLStream.html#a91babbdc474e6a01e602ad5d21c58710',1,'PLStream']]],
  ['widthset',['widthset',['../structPLStream.html#a812c6e5e4d84453944c67784f43b2411',1,'PLStream']]],
  ['window',['window',['../structTkwDev.html#a143e4e7685a6f27acf861dc819dc2154',1,'TkwDev::window()'],['../structXwDev.html#a18e08f1211cc3a9d9320506f1cb0f251',1,'XwDev::window()']]],
  ['window_5fid',['window_id',['../structPLStream.html#a209b4e2760c7744dcc04912330249551',1,'PLStream']]],
  ['windowxsize',['windowXSize',['../aqt_8c.html#aa18d84ecb5a0965996ad8bbbe7ba7ef2',1,'aqt.c']]],
  ['windowysize',['windowYSize',['../aqt_8c.html#a19833fbb8fb8cf68809de7b4e1373ebb',1,'aqt.c']]],
  ['wmin',['wmin',['../structnnai.html#aa382af28cedb0b28813e89076c97da20',1,'nnai::wmin()'],['../structnnpi.html#aec08e963c5c5d792cfa191b6b5046fa7',1,'nnpi::wmin()']]],
  ['wmxoff',['wmxoff',['../structPLStream.html#aea4c297c42f3e7e2d3fd21dee421d53a',1,'PLStream']]],
  ['wmxscl',['wmxscl',['../structPLStream.html#ab4124f5acbd397314da02d08f6e29174',1,'PLStream']]],
  ['wmyoff',['wmyoff',['../structPLStream.html#a4b1ed19b6eaa67093322e029692b59b1',1,'PLStream']]],
  ['wmyscl',['wmyscl',['../structPLStream.html#a5a70268fa1d38b34ccf0a3336f58de0a',1,'PLStream']]],
  ['wp',['wp',['../classplplot__double.html#a1e6e7ad2d5490ae8717d2a0ce32690d8',1,'plplot_double::wp()'],['../classplplot__single.html#a197b7deb1258c3fee8e5ebbdf78390b3',1,'plplot_single::wp()']]],
  ['wpxoff',['wpxoff',['../structPLStream.html#a28fc8e7991a0824a135450fca3304966',1,'PLStream']]],
  ['wpxscl',['wpxscl',['../structPLStream.html#a3f07edd33b6774ecc1e1a5df3e7e7072',1,'PLStream']]],
  ['wpyoff',['wpyoff',['../structPLStream.html#afb689ff0653205319126b01be493409f',1,'PLStream']]],
  ['wpyscl',['wpyscl',['../structPLStream.html#a386fb51e8daea7f899c61edd02b589be',1,'PLStream']]],
  ['write_5fto_5fpixmap',['write_to_pixmap',['../structTkwDev.html#a7fa913fd6464fe34fa219fcaaf1f2cbe',1,'TkwDev::write_to_pixmap()'],['../structXwDev.html#ae88d0a77b383c2a295bb2d0ea27b511c',1,'XwDev::write_to_pixmap()']]],
  ['write_5fto_5fwindow',['write_to_window',['../structTkwDev.html#a770d670846a19fa7c10cb10e62fee84c',1,'TkwDev::write_to_window()'],['../structXwDev.html#a1f9edf6540ee93db1f82dd87a0a2bb6b',1,'XwDev::write_to_window()']]],
  ['writelocation',['writeLocation',['../structMemoryMapHeader.html#a74a1cd16e4e3777dff8460a9bdb3625b',1,'MemoryMapHeader']]],
  ['written',['written',['../structTextSizeInfo.html#abdc25237fa37dbc3af4b2a3fb23f9c6c',1,'TextSizeInfo']]],
  ['wx',['wx',['../structplplot__graphics_1_1plgraphicsin.html#ad3f0d5a7ba1f96326a40c647651b5915',1,'plplot_graphics::plgraphicsin::wx()'],['../structplplot_1_1__N2.html#a935c6c7e9145c1fca94cb1a701b6964a',1,'plplot::_N2::wX()'],['../structPLGraphicsIn.html#a5b265dd393e9731157ecf8bc421bc479',1,'PLGraphicsIn::wX()']]],
  ['wxma',['wxma',['../structplplot_1_1__N3.html#a6ddaaba61af2c4b662271fcf40dfbcf3',1,'plplot::_N3::wxma()'],['../structPLWindow.html#ab0553bb8419bd38e6423067bb8eea203',1,'PLWindow::wxma()']]],
  ['wxmax',['wxmax',['../structPLStrip.html#a4b645ccf065628700a5da497eeb65058',1,'PLStrip']]],
  ['wxmi',['wxmi',['../structplplot_1_1__N3.html#ab93302bcc38c067ef896a4a25d4bd6ad',1,'plplot::_N3::wxmi()'],['../structPLWindow.html#a890a5eac4d14c0b40c366e105136fb40',1,'PLWindow::wxmi()']]],
  ['wxmin',['wxmin',['../structPLStrip.html#ab5f92f592afcb4cf7492ffa0eea684cd',1,'PLStrip']]],
  ['wy',['wY',['../structplplot_1_1__N2.html#a1df90e14d71a619b0f913d4a9c36dfff',1,'plplot::_N2::wY()'],['../structPLGraphicsIn.html#a5d79945d06cba50e5e44cc62543312f3',1,'PLGraphicsIn::wY()'],['../structplplot__graphics_1_1plgraphicsin.html#a7cbe9e4c6e109e34c8f188bca3a5cf21',1,'plplot_graphics::plgraphicsin::wy()']]],
  ['wyma',['wyma',['../structplplot_1_1__N3.html#af010eafb3691279a6ceefe4a74d8f511',1,'plplot::_N3::wyma()'],['../structPLWindow.html#aa3aa6d82105e1dba93aea120c7d1cb8e',1,'PLWindow::wyma()']]],
  ['wymax',['wymax',['../structPLStrip.html#a5a960af3e30dc05698c37f437ff0f15d',1,'PLStrip']]],
  ['wymi',['wymi',['../structplplot_1_1__N3.html#a49647d2648e79fda9f0b87637f842aef',1,'plplot::_N3::wymi()'],['../structPLWindow.html#a7b5922ecc2033a58c94224d4985d7a7c',1,'PLWindow::wymi()']]],
  ['wymin',['wymin',['../structPLStrip.html#a895a49fcfcf636dcd819c8a009d6885e',1,'PLStrip']]]
];

==> plplot-5.15.0.tar.gz: plplot-5.15.0/doc/doxygen/html/search/variables_17.js <==
var searchData=
[
  ['w',['w',['../structlweights.html#af40aaef04f119296b33813a0225e00e3',1,'lweights::w()'],['../structTkDev.html#a4c322c4c38c122f4e60fdd8c2296e85d',1,'TkDev::w()']]],
  ['wdxoff',['wdxoff',['../structPLStream.html#a6916b03e47be96ff859874fa15f98fa6',1,'PLStream']]],
  ['wdxscl',['wdxscl',['../structPLStream.html#a36fef6d794ee3daeb1e22fb9552d499a',1,'PLStream']]],
  ['wdyoff',['wdyoff',['../structPLStream.html#a732b5abcb2edb9375695bd9c61e98272',1,'PLStream']]],
  ['wdyscl',['wdyscl',['../structPLStream.html#a1ddb0104b923970d0889e9bcb9820aef',1,'PLStream']]],
  ['weight',['weight',['../structTextSizeInfo.html#afa663f4b7f4f6c2aa0551b8e27d70eef',1,'TextSizeInfo']]],
  ['weightlookup',['weightLookup',['../cairo_8c.html#a8ee4cf3cd65bc4579b564af38718e76e',1,'weightLookup():&#160;cairo.c'],['../psttf_8cc.html#a9ec93d57a07d213d1c836c6c932d5d1c',1,'WeightLookup():&#160;psttf.cc']]],
  ['weights',['weights',['../structlpi.html#a47f09ca005a3a4725ac531d7c1b4a178',1,'lpi::weights()'],['../structnn__weights.html#aa7ff68d9ad8e6499da44ae1ea326f368',1,'nn_weights::weights()'],['../structnnai.html#a864b1bcffbc680629d3c0efeff6d0529',1,'nnai::weights()'],['../structnnpi.html#a5f9dd37ee1ee5fe193df92df14c81875',1,'nnpi::weights()']]],
  ['which_5fclip',['which_clip',['../structSVG.html#ac28d8f81f49562a61c7de7004a0d80a4',1,'SVG']]],
  ['widgetcmd',['widgetCmd',['../structPlPlotter.html#ac8c81c96fb8f23a67e730995fe5ebb9d',1,'PlPlotter']]],
  ['width',['width',['../structTextSizeInfo.html#ab1af6b6260151c04950802322d3daeaf',1,'TextSizeInfo::width()'],['../structplplot_1_1__N4.html#a0f3ef32d5b1784d76004730694a84a8b',1,'plplot::_N4::width()'],['../structPlFrame.html#acc698d3e2671b7ef5a041c04f01dae1c',1,'PlFrame::width()'],['../structTkDev.html#acd6af46bd1c788770c0615962e8119b6',1,'TkDev::width()'],['../structPlPlotter.html#a0242cfa1d0dc49a4f1ffac8d5ae01459',1,'PlPlotter::width()'],['../structTkwDev.html#a11a01cf9504ca9f31486d9508646c8b4',1,'TkwDev::width()'],['../structPLDisplay.html#ae8787ffc7a95b8ebcd7c991e97c1452c',1,'PLDisplay::width()'],['../structPLStream.html#a5ee6732e0c80f6ee27d5588100f07cb7',1,'PLStream::width()'],['../structXwDev.html#a490aa0f52841cfabe6eaf2bdde560989',1,'XwDev::width()']]],
  ['widthlock',['widthlock',['../structPLStream.html#a91babbdc474e6a01e602ad5d21c58710',1,'PLStream']]],
  ['widthset',['widthset',['../structPLStream.html#a812c6e5e4d84453944c67784f43b2411',1,'PLStream']]],
  ['window',['window',['../structTkwDev.html#a143e4e7685a6f27acf861dc819dc2154',1,'TkwDev::window()'],['../structXwDev.html#a18e08f1211cc3a9d9320506f1cb0f251',1,'XwDev::window()']]],
  ['window_5fid',['window_id',['../structPLStream.html#a209b4e2760c7744dcc04912330249551',1,'PLStream']]],
  ['windowxsize',['windowXSize',['../aqt_8c.html#aa18d84ecb5a0965996ad8bbbe7ba7ef2',1,'aqt.c']]],
  ['windowysize',['windowYSize',['../aqt_8c.html#a19833fbb8fb8cf68809de7b4e1373ebb',1,'aqt.c']]],
  ['wmin',['wmin',['../structnnai.html#aa382af28cedb0b28813e89076c97da20',1,'nnai::wmin()'],['../structnnpi.html#aec08e963c5c5d792cfa191b6b5046fa7',1,'nnpi::wmin()']]],
  ['wmxoff',['wmxoff',['../structPLStream.html#aea4c297c42f3e7e2d3fd21dee421d53a',1,'PLStream']]],
  ['wmxscl',['wmxscl',['../structPLStream.html#ab4124f5acbd397314da02d08f6e29174',1,'PLStream']]],
  ['wmyoff',['wmyoff',['../structPLStream.html#a4b1ed19b6eaa67093322e029692b59b1',1,'PLStream']]],
  ['wmyscl',['wmyscl',['../structPLStream.html#a5a70268fa1d38b34ccf0a3336f58de0a',1,'PLStream']]],
  ['wp',['wp',['../namespaceplplot__double.html#a1e6e7ad2d5490ae8717d2a0ce32690d8',1,'plplot_double::wp()'],['../namespaceplplot__single.html#a197b7deb1258c3fee8e5ebbdf78390b3',1,'plplot_single::wp()']]],
  ['wpxoff',['wpxoff',['../structPLStream.html#a28fc8e7991a0824a135450fca3304966',1,'PLStream']]],
  ['wpxscl',['wpxscl',['../structPLStream.html#a3f07edd33b6774ecc1e1a5df3e7e7072',1,'PLStream']]],
  ['wpyoff',['wpyoff',['../structPLStream.html#afb689ff0653205319126b01be493409f',1,'PLStream']]],
  ['wpyscl',['wpyscl',['../structPLStream.html#a386fb51e8daea7f899c61edd02b589be',1,'PLStream']]],
  ['write_5fto_5fpixmap',['write_to_pixmap',['../structTkwDev.html#a7fa913fd6464fe34fa219fcaaf1f2cbe',1,'TkwDev::write_to_pixmap()'],['../structXwDev.html#ae88d0a77b383c2a295bb2d0ea27b511c',1,'XwDev::write_to_pixmap()']]],
  ['write_5fto_5fwindow',['write_to_window',['../structTkwDev.html#a770d670846a19fa7c10cb10e62fee84c',1,'TkwDev::write_to_window()'],['../structXwDev.html#a1f9edf6540ee93db1f82dd87a0a2bb6b',1,'XwDev::write_to_window()']]],
  ['writelocation',['writeLocation',['../structMemoryMapHeader.html#a74a1cd16e4e3777dff8460a9bdb3625b',1,'MemoryMapHeader']]],
  ['written',['written',['../structTextSizeInfo.html#abdc25237fa37dbc3af4b2a3fb23f9c6c',1,'TextSizeInfo']]],
  ['wx',['wX',['../structplplot_1_1__N2.html#a935c6c7e9145c1fca94cb1a701b6964a',1,'plplot::_N2::wX()'],['../structPLGraphicsIn.html#a5b265dd393e9731157ecf8bc421bc479',1,'PLGraphicsIn::wX()'],['../classplplotc_1_1PLGraphicsIn.html#a8ed87c312f9d3ee231ed74532d51ce04',1,'plplotc.PLGraphicsIn.wX()'],['../structplplot__graphics_1_1plgraphicsin.html#ad3f0d5a7ba1f96326a40c647651b5915',1,'plplot_graphics::plgraphicsin::wx()']]],
  ['wxma',['wxma',['../structplplot_1_1__N3.html#a6ddaaba61af2c4b662271fcf40dfbcf3',1,'plplot::_N3::wxma()'],['../structPLWindow.html#ab0553bb8419bd38e6423067bb8eea203',1,'PLWindow::wxma()']]],
  ['wxmax',['wxmax',['../structPLStrip.html#a4b645ccf065628700a5da497eeb65058',1,'PLStrip']]],
  ['wxmi',['wxmi',['../structplplot_1_1__N3.html#ab93302bcc38c067ef896a4a25d4bd6ad',1,'plplot::_N3::wxmi()'],['../structPLWindow.html#a890a5eac4d14c0b40c366e105136fb40',1,'PLWindow::wxmi()']]],
  ['wxmin',['wxmin',['../structPLStrip.html#ab5f92f592afcb4cf7492ffa0eea684cd',1,'PLStrip']]],
  ['wy',['wY',['../structplplot_1_1__N2.html#a1df90e14d71a619b0f913d4a9c36dfff',1,'plplot::_N2::wY()'],['../structPLGraphicsIn.html#a5d79945d06cba50e5e44cc62543312f3',1,'PLGraphicsIn::wY()'],['../classplplotc_1_1PLGraphicsIn.html#a785b37083887a714c9a741c95546e609',1,'plplotc.PLGraphicsIn.wY()'],['../structplplot__graphics_1_1plgraphicsin.html#a7cbe9e4c6e109e34c8f188bca3a5cf21',1,'plplot_graphics::plgraphicsin::wy()']]],
  ['wyma',['wyma',['../structplplot_1_1__N3.html#af010eafb3691279a6ceefe4a74d8f511',1,'plplot::_N3::wyma()'],['../structPLWindow.html#aa3aa6d82105e1dba93aea120c7d1cb8e',1,'PLWindow::wyma()']]],
  ['wymax',['wymax',['../structPLStrip.html#a5a960af3e30dc05698c37f437ff0f15d',1,'PLStrip']]],
  ['wymi',['wymi',['../structplplot_1_1__N3.html#a49647d2648e79fda9f0b87637f842aef',1,'plplot::_N3::wymi()'],['../structPLWindow.html#a7b5922ecc2033a58c94224d4985d7a7c',1,'PLWindow::wymi()']]],
  ['wymin',['wymin',['../structPLStrip.html#a895a49fcfcf636dcd819c8a009d6885e',1,'PLStrip']]]
];
